@@ -48,79 +48,79 @@ Readonly::Scalar our $CONFIGURATION_BACKUP_ID  =>'configuration backup';
 Readonly::Scalar our $BUGREPORT_BACKUP_ID  =>'bugreport configuration dump';
 my $RECURSIVE_DEPENDENCY_THRESHOLD = 3;
 
-sub new 
+sub new
 {
-	my $class = shift;
-	my $self = {};
-	bless($self, $class);
-	return $self;
+    my $class = shift;
+    my $self = {};
+    bless($self, $class);
+    return $self;
 }
 
 # returns:
-# 	string: path to the backup file.
-sub _makeBackup # (description, bug?) 
+#       string: path to the backup file.
+sub _makeBackup # (description, bug?)
 {
-	my ($self, %options) = @_;
+    my ($self, %options) = @_;
 
-	my $description = delete $options{description};
+    my $description = delete $options{description};
 
-	my $bug         = $options{bug};
-	my $progress   = $options{progress};
+    my $bug         = $options{bug};
+    my $progress   = $options{progress};
 
-	my $time = strftime("%F %T", localtime);
+    my $time = strftime("%F %T", localtime);
 
-	my $confdir = EBox::Config::conf;
-	my $tempdir = tempdir("$confdir/backup.XXXXXX") or
-		throw EBox::Exceptions::Internal("Could not create tempdir.");
-	EBox::Sudo::command("chmod 0700 $tempdir");
+    my $confdir = EBox::Config::conf;
+    my $tempdir = tempdir("$confdir/backup.XXXXXX") or
+        throw EBox::Exceptions::Internal("Could not create tempdir.");
+    EBox::Sudo::command("chmod 0700 $tempdir");
 
-	my $auxDir = "$tempdir/aux";
-	my $archiveContentsDirRelative = "eboxbackup";
-	my $archiveContentsDir = "$tempdir/$archiveContentsDirRelative";
-	my $backupArchive = "$confdir/eboxbackup.tar";
-	
-	try {
-	  mkdir($auxDir, 0700) or
-	    throw EBox::Exceptions::Internal("Could not create auxiliar tempdir.");
-	  mkdir($archiveContentsDir, 0700) or
-	    throw EBox::Exceptions::Internal("Could not create archive tempdir.");
+    my $auxDir = "$tempdir/aux";
+    my $archiveContentsDirRelative = "eboxbackup";
+    my $archiveContentsDir = "$tempdir/$archiveContentsDirRelative";
+    my $backupArchive = "$confdir/eboxbackup.tar";
 
-	  $self->_dumpModulesBackupData($auxDir, %options);
+    try {
+        mkdir($auxDir, 0700) or
+            throw EBox::Exceptions::Internal("Could not create auxiliar tempdir.");
+        mkdir($archiveContentsDir, 0700) or
+            throw EBox::Exceptions::Internal("Could not create archive tempdir.");
 
-	  if ($bug) {
-	    $self->_bug($auxDir);
-	  }
+          $self->_dumpModulesBackupData($auxDir, %options);
+
+        if ($bug) {
+            $self->_bug($auxDir);
+        }
 
 
-	  if ($progress) {
-	    $progress->setMessage(__('Creating backup archive'));
-	    $progress->notifyTick();
-	  }
+        if ($progress) {
+            $progress->setMessage(__('Creating backup archive'));
+            $progress->notifyTick();
+        }
 
 
 
-	  my $filesArchive  = "$archiveContentsDir/files.tgz";
-	  $self->_createFilesArchive($auxDir, $filesArchive);
-	  $self->_createMd5DigestForArchive($filesArchive, $archiveContentsDir);
-	  $self->_createDescriptionFile($archiveContentsDir, $description);
-	  $self->_createDateFile($archiveContentsDir, $time);
-	  $self->_createTypeFile($archiveContentsDir, $options{fullBackup}, $bug);
-	  $self->_createModulesListFile($archiveContentsDir);
+        my $filesArchive  = "$archiveContentsDir/files.tgz";
+        $self->_createFilesArchive($auxDir, $filesArchive);
+        $self->_createMd5DigestForArchive($filesArchive, $archiveContentsDir);
+        $self->_createDescriptionFile($archiveContentsDir, $description);
+        $self->_createDateFile($archiveContentsDir, $time);
+        $self->_createTypeFile($archiveContentsDir, $options{fullBackup}, $bug);
+        $self->_createModulesListFile($archiveContentsDir);
 
-	  $self->_createSizeFile($archiveContentsDir);
+        $self->_createSizeFile($archiveContentsDir);
 
-	  $self->_createBackupArchive($backupArchive, $tempdir, $archiveContentsDirRelative);
+        $self->_createBackupArchive($backupArchive, $tempdir, $archiveContentsDirRelative);
 
 
-	}
-	finally {
-	  system "rm -rf $tempdir";
-	  if ($? != 0) {
-	    EBox::error("$auxDir cannot be deleted: $!. Please do it manually");
-	  }
-	};
+    }
+    finally {
+        system "rm -rf '$tempdir'";
+        if ($? != 0) {
+            EBox::error("$auxDir cannot be deleted: $!. Please do it manually");
+        }
+    };
 
-	return $backupArchive;
+    return $backupArchive;
 }
 
 
@@ -133,21 +133,18 @@ sub _dumpModulesBackupData
   my @modules = @{ $self->_modInstancesForBackup() };
   foreach my $mod (@modules) {
     my $modName = $mod->name();
-    # XXX temporally skipping logs
-    next if $modName eq 'logs';
 
     if ($progress) {
       # update progress object
       $progress->notifyTick();
       $progress->setMessage(__x('Dumping configuration of module {m}',
-			      m => $modName));
-    }
-
+                              m => $modName));
+  }
 
     try {
       EBox::debug("Dumping $modName backup data");
       $mod->makeBackup($auxDir, %options);
-    } 
+    }
     catch EBox::Exceptions::Base with {
       my $ex = shift;
       throw EBox::Exceptions::Internal($ex->text);
@@ -179,7 +176,7 @@ sub _configuredModInstances
   foreach my $mod (@modules) {
     if ($mod->can('configured')) {
       if ($mod->configured()) {
-	push @configuredModules, $mod;
+        push @configuredModules, $mod;
       }
     }
     else {
@@ -188,8 +185,8 @@ sub _configuredModInstances
   }
   # leave aside not configured modules
 #   @modules = grep {
-# #    (not $_->isa('EBox::ServiceModule::ServiceInterface') or
-# #    ($_->configured())) 
+# #    (not $_->isa('EBox::Module::Service') or
+# #    ($_->configured()))
 #     $_->configured()
 #   } @modules;
 
@@ -201,12 +198,12 @@ sub  _createFilesArchive
 {
   my ($self, $auxDir, $filesArchive) = @_;
 
-  if (`umask 0077; tar czf $filesArchive -C $auxDir .`) {
+  if (`umask 0077; tar czf '$filesArchive' -C '$auxDir' .`) {
     throw EBox::Exceptions::Internal("Could not create archive.");
   }
-  `rm -rf $auxDir`;
+  system "rm -rf '$auxDir'";
 
-} 
+}
 
 sub  _createDateFile
 {
@@ -218,7 +215,7 @@ sub  _createDateFile
   }
   print $DATE  $time ;
   close($DATE);
-} 
+}
 
 sub  _createDescriptionFile
 {
@@ -230,15 +227,15 @@ sub  _createDescriptionFile
   }
   print $DESC $description;
   close($DESC);
-} 
+}
 
 sub  _createTypeFile
 {
   my ($self, $archiveContentsDir, $fullBackup, $bug) = @_;
 
-  my $type =    $bug        ? $BUGREPORT_BACKUP_ID 
-              : $fullBackup ?  $FULL_BACKUP_ID 
-	      :	$CONFIGURATION_BACKUP_ID;
+  my $type =    $bug        ? $BUGREPORT_BACKUP_ID
+              : $fullBackup ?  $FULL_BACKUP_ID
+              : $CONFIGURATION_BACKUP_ID;
 
   my $TYPE_F;
   unless (open($TYPE_F, "> $archiveContentsDir/type")) {
@@ -246,12 +243,12 @@ sub  _createTypeFile
   }
   print $TYPE_F $type;
   close($TYPE_F);
-} 
+}
 
 sub _createMd5DigestForArchive
 {
   my ($self, $filesArchive, $archiveContentsDir) = @_;
-  
+
   my $ARCHIVE;
   unless (open($ARCHIVE, $filesArchive)) {
     throw EBox::Exceptions::Internal("Could not open files archive.");
@@ -279,7 +276,7 @@ sub  _createModulesListFile
 
   my $file = "$archiveContentsDir/modules";
   write_file($file, "@modNames");
-} 
+}
 
 sub  _createBackupArchive
 {
@@ -287,7 +284,7 @@ sub  _createBackupArchive
 
   if ( -f $backupArchive) {
     if (`rm -f $backupArchive`) {
-      throw EBox::Exceptions::Internal	("Could not delete old file.");
+      throw EBox::Exceptions::Internal  ("Could not delete old file.");
     }
   }
 
@@ -302,58 +299,62 @@ sub  _createBackupArchive
     throw EBox::Exceptions::External(__('Could not create backup archive'));
   }
 
-  $cmd = "tar --append -f $backupArchive  -C $tempdir $filesArchive 2>&1";
+  $cmd = "tar --append -f '$backupArchive'  -C '$tempdir' '$filesArchive' 2>&1";
   @output = `$cmd`;
   if ($? != 0) {
     EBox::error("Failed command: $cmd. Output: @output");
     throw EBox::Exceptions::External(__('Could not append data to backup archive'));
   }
-} 
+}
 
 sub _createSizeFile
 {
   my ($self,  $archiveContentsDir) = @_;
   my $size;
-  
+
   my $duCommand = "du -b -s -c --block-size=1024 $archiveContentsDir";
   my $output    = EBox::Sudo::command($duCommand);
   my ($totalLine) = grep { m/total/  } @{ $output  };
-  ($size) = split '\s', $totalLine; 
+  ($size) = split '\s', $totalLine;
 
   my $sizeFile = "$archiveContentsDir/size";
   write_file($sizeFile, $size)
-} 
+}
 
 
 
-sub _bug # (dir) 
+sub _bug # (dir)
 {
-	my ($self, $dir) = @_;
-	`/bin/ps aux > $dir/processes`;
-	`/bin/df -k > $dir/disks`;
-	`/bin/netstat -n -a --inet > $dir/sockets`;
-	`/sbin/ifconfig -a > $dir/interfaces`;
+    my ($self, $dir) = @_;
 
-	try {
-		root("/sbin/iptables -nvL > $dir/iptables-filter");
-	} catch EBox::Exceptions::Base with {};
+    system "/bin/ps aux > $dir/processes";
+    system "/bin/df -k > $dir/disks";
+    system "/sbin/route -n  > $dir/routes";
+    system "/bin/netstat -n -a --inet > $dir/sockets";
+    system "/sbin/ifconfig -a > $dir/interfaces";
+    system "cp /etc/resolv.conf  $dir/resolv.conf";
+    system "dpkg -l > $dir/debpackages";
 
-	try {
-		root("/sbin/iptables -t nat -nvL > $dir/iptables-nat");
-	} catch EBox::Exceptions::Base with {};
+    try {
+        root("/sbin/iptables -nvL > $dir/iptables-filter");
+    } catch EBox::Exceptions::Base with {};
 
-	copy(EBox::Config::logfile, "$dir/ebox.log");
-	copy(EBox::Config::log . "/error.log", "$dir/error.log");
-	copy("/var/log/syslog", "$dir/syslog");
-	copy("/var/log/messages", "$dir/messages");
-	copy("/var/log/daemon.log", "$dir/daemon.log");
-	copy("/var/log/auth.log", "$dir/auth.log");
+    try {
+        root("/sbin/iptables -t nat -nvL > $dir/iptables-nat");
+    } catch EBox::Exceptions::Base with {};
+
+    copy(EBox::Config::logfile, "$dir/ebox.log");
+    copy(EBox::Config::log . "/error.log", "$dir/error.log");
+    copy("/var/log/syslog", "$dir/syslog");
+    copy("/var/log/messages", "$dir/messages");
+    copy("/var/log/daemon.log", "$dir/daemon.log");
+    copy("/var/log/auth.log", "$dir/auth.log");
 }
 
 #
-# Method: backupDetails 
+# Method: backupDetails
 #
-#   	Gathers the information for a given backup
+#       Gathers the information for a given backup
 #
 # Parameters:
 #
@@ -362,14 +363,14 @@ sub _bug # (dir)
 # Returns:
 #
 #       A hash reference with the details. This hash consists of:
-#	
-#       file - the filename of the archive
-#	id - backup's identifier
-#	date - when it was backed up
-#       type - the type of backup
-#	description - backup's description
 #
-sub backupDetails # (id) 
+#       file - the filename of the archive
+#       id - backup's identifier
+#       date - when it was backed up
+#       type - the type of backup
+#       description - backup's description
+#
+sub backupDetails # (id)
 {
   my ($self, $id) = @_;
   validate_pos(@_, 1, ,1);
@@ -380,7 +381,7 @@ sub backupDetails # (id)
 
   my $details = $self->backupDetailsFromArchive($file);
   $details->{id} = $id;
-  
+
   return $details;
 }
 
@@ -393,15 +394,15 @@ sub backupDetails # (id)
 #
 # Parameters:
 #       archive - the path to the archive file
-#       
+#
 #
 # Returns:
 #
 #       A hash reference with the details. This hash consists of:
-#	
+#
 #       file - the filename of the archive
-#	date - when it was backed up
-#	description - backup's description
+#       date - when it was backed up
+#       description - backup's description
 #       type        - the type of backup contained by the archive
 sub backupDetailsFromArchive
 {
@@ -427,12 +428,31 @@ sub backupDetailsFromArchive
     close $FH;
   }
 
-  $backupDetails->{file} = $archive; 
+  $backupDetails->{file} = $archive;
+  $backupDetails->{size} = $self->_printableSize($archive);
 
-  system "rm -rf $tempDir";
+  system "rm -rf '$tempDir'";
   return $backupDetails;
 }
 
+
+sub _printableSize
+{
+    my ($self, $archive) = @_;
+
+    my $size = (-s $archive);
+
+    my @units = qw(KB MB GB);
+    foreach my $unit (@units) {
+        $size = sprintf ("%.2f", $size / 1024);
+        if ($size < 1024) {
+            return "$size $unit";
+        }
+    }
+
+    return $size . ' ' . (pop @units);
+}
+
 # if not specific files are specified all the fiels are  extracted
 sub _unpackArchive
 {
@@ -444,25 +464,25 @@ sub _unpackArchive
   EBox::Sudo::command("chmod 0700 $tempDir");
 
   my $filesWithPath =  @files > 0 ?
-    join ' ', map { 'eboxbackup/' . $_  } @files : '';
+    join ' ', map { q{'eboxbackup/} . $_  . q{'} } @files : '';
 
   try {
-    
-    my $tarCommand = "/bin/tar xf $archive -C $tempDir $filesWithPath";
+
+    my $tarCommand = "/bin/tar xf '$archive' -C '$tempDir' $filesWithPath";
     if (system $tarCommand) {
       if (@files > 0) {
-	throw EBox::Exceptions::External( __x("Could not extract the requested backup files: {files}", files => "@files"));
+        throw EBox::Exceptions::External( __x("Could not extract the requested backup files: {files}", files => "@files"));
       }
       else {
-	throw EBox::Exceptions::External( __("Could not unpack the backup"));
+        throw EBox::Exceptions::External( __("Could not unpack the backup"));
       }
     }
 
   }
   otherwise {
     my $ex = shift;
-    
-    system("rm -rf $tempDir");
+
+    system("rm -rf '$tempDir'");
     ($? == 0) or EBox::warning("Unable to remove $tempDir. Please do it manually");
 
     $ex->throw();
@@ -473,9 +493,9 @@ sub _unpackArchive
 
 
 #
-# Method: deleteBackup 
+# Method: deleteBackup
 #
-#   	Romoves a stored backup	
+#       Romoves a stored backup
 #
 # Parameters:
 #
@@ -483,14 +503,14 @@ sub _unpackArchive
 #
 # Exceptions:
 #
-#     	External -  If it can't be found or deleted.
-sub deleteBackup # (id) 
+#       External -  If it can't be found or deleted.
+sub deleteBackup # (id)
 {
   my ($self, $id) = @_;
   validate_pos(@_, 1, 1);
 
   $self->_checkId($id);
-	
+
   my $file = $self->_backupFileById($id);
 
   unless (unlink($file)) {
@@ -500,9 +520,9 @@ sub deleteBackup # (id)
 
 
 #
-# Method: listBackups 
+# Method: listBackups
 #
-#   	Returns a list with the availible backups stored in the system.	
+#       Returns a list with the availible backups stored in the system.
 #
 # Parameters:
 #
@@ -511,45 +531,49 @@ sub deleteBackup # (id)
 # Returns:
 #
 #       A a ref to an array of hashes. Each  hash reference consists of:
-#	
-#	id - backup's identifier
-#	date - when it was backed up
-#	description - backup's description
+#
+#       id - backup's identifier
+#       date - when it was backed up
+#       description - backup's description
 #       type        - type of backup (full or configuration only)
 #
 sub listBackups
 {
-	my $self = shift;
-	my $backupdir = backupDir();
-	my $bh = new DirHandle($backupdir);
-	my @backups = ();
-	my $backup;
-	($bh) or return \@backups;
-	while (defined($backup = $bh->read)) {
-		(-f "$backupdir/$backup") or next;
-		$backup =~ s/\.tar$//;
-		my $entry = undef;
-		try {
-			$entry = $self->backupDetails($backup);
-		} catch EBox::Exceptions::Base with {};
-		unless ($entry) {
-			unlink("$backupdir/$backup.tar");
-			next;
-		}
-		push(@backups, $entry);
-	}
-	undef $bh;
-	my @ret = sort {$a->{date} lt $b->{date}} @backups;
-	return \@ret;
+    my ($self) = @_;
+    my $backupdir = backupDir();
+    my $bh = new DirHandle($backupdir);
+    my @backups = ();
+    my $backup;
+    ($bh) or return \@backups;
+    while (defined($backup = $bh->read)) {
+        (-f "$backupdir/$backup") or next;
+        my $isTar = $backup =~ s/\.tar$//;
+
+        $isTar or
+            next;
+
+        my $entry = undef;
+        try {
+            $entry = $self->backupDetails($backup);
+        } catch EBox::Exceptions::Base with {};
+        unless ($entry) {
+            EBox::info("File $backupdir.$backup.tar is in backup directorty and is not a backup file");
+            next;
+        }
+        push(@backups, $entry);
+    }
+    undef $bh;
+    my @ret = sort {$a->{date} lt $b->{date}} @backups;
+    return \@ret;
 }
 
 #
-# Procedure: backupDir  
+# Procedure: backupDir
+#
+# Returns:
+#       the directory used by ebox to store the backup archives
 #
-# Returns: 
-#       the directory used by ebox to store the backup archives 
 #
-# 
 sub backupDir
 {
   my $backupdir = EBox::Config::conf . '/backups';
@@ -566,8 +590,8 @@ sub _ensureBackupdirExistence
       ("Could not create backupdir.");
   }
 
-  
-} 
+
+}
 
 
 
@@ -575,41 +599,70 @@ sub _ensureBackupdirExistence
 #
 # Method: prepareMakeBackup
 #
-#   	Prepares a backup restauration 
+#       Prepares a backup restauration
 #
 # Parameters:
 #
-#                   description - backup's description (backwards compability mode)
-#                   fullBackup  - wether do a full backup or  backup only configuration (default: false)
+#                   description - backup's description (default: 'Backup')
+#                   fullBackup  - whether do a full backup or  backup only configuration (default: false)
+#                   bug         - whether this backup is intended for a bug report
+#                                 (one consequence of this is that we must clear
+#                                  private data)
 #
-#  Returns:
-#    the progress indicator object whihc represents the progress of the restauration
+#                   remoteBackup -- whether this a backup intended to be a remote backup
+#
+# Returns:
+#     progress indicator object of the operation
 #
 # Exceptions:
-#	
-#	External - If it can't unpack de backup
+#
+#       External - If it can't unpack de backup
 #
 sub prepareMakeBackup
 {
   my ($self, %options) = @_;
 
-  # make sure description is scaped
-  $options{description} = q{'} . $options{description} . q{'};
-  my @scriptParams = %options; 
+  my $scriptParams = '';
+
+  if ( $options{remoteBackup} ) {
+      $scriptParams .= ' --remote-backup ';
+      # Make sure remote backup name is scaped
+      $scriptParams .= q{'} . $options{remoteBackup} . q{'};
+  }
+
+  if (exists $options{description}) {
+      $scriptParams .= ' --description ';
+      # make sure description is scaped
+      $scriptParams .= q{'} . $options{description} . q{'};
+  }
+
+  if ($options{fullBackup}) {
+      $scriptParams .= ' --full-backup';
+  }
+  else {
+      $scriptParams .= ' --config-backup';
+  }
+
+  if ($options{bug}) {
+      $scriptParams .= ' --bug-report';
+  }
 
   my $makeBackupScript = EBox::Config::pkgdata() . 'ebox-make-backup';
-  $makeBackupScript    .= "  @scriptParams";
-  
+  $makeBackupScript    .=  $scriptParams;
+
   my $global     = EBox::Global->getInstance();
-  my $totalTicks = scalar @{ $global->modNames } + 2; # there are one task for
+  my $totalTicks = scalar @{ $global->modNames() } + 2; # there are one task for
                                                       # each module plus two
                                                       # tasks for writing the
                                                       # archive  file
-           
+
+  my @progressIndicatorParams = (
+                             executable => $makeBackupScript,
+                             totalTicks => $totalTicks,
+                                                    );
 
   my $progressIndicator =  EBox::ProgressIndicator->create(
-			     executable => $makeBackupScript,
-			     totalTicks => $totalTicks,
+							@progressIndicatorParams
 						    );
 
   $progressIndicator->runExecutable();
@@ -619,35 +672,41 @@ sub prepareMakeBackup
 
 
 #
-# Method: makeBackup 
+# Method: makeBackup
 #
-#   	Backups the current configuration	
+#       Backups the current configuration
 #
 # Parameters:
 #
-#                   progress-  progress indicator 
+#                   progress-  progress indicator
 #                       associated with this operation (optionak)
 #                   description - backup's description (default: 'Backup')
-#                   fullBackup  - wether do a full backup or  backup only configuration (default: false)
+#                   fullBackup  - whether do a full backup or  backup only configuration (default: false)
+#                   bug         - whether this backup is intended for a bug report
+#                                 (one consequence of this is that we must clear
+#                                  private data)
+#
+#  Returns:
+#         - path to the new backup archive
 #
 # Exceptions:
-#	
-#	Internal - If backup fails
-#       Exteanl   - If modules have unsaved changes
-sub makeBackup # (options) 
+#
+#       Internal - If backup fails
+#       External - If modules have unsaved changes
+sub makeBackup # (options)
 {
   my ($self, %options) = @_;
   validate_with(
-		params => [%options],
-		spec   => {
-			   progress     => { 
-					    optional => 1, 
-					     isa => 'EBox::ProgressIndicator'
-					   },
-			   description => { default =>  __('Backup') },
-			   fullBackup  => { default => 0 },
-			   bug         => { default => 0},
-			  });
+                params => [%options],
+                spec   => {
+                           progress     => {
+                                            optional => 1,
+                                             isa => 'EBox::ProgressIndicator'
+                                           },
+                           description => { default =>  __('Backup') },
+                           fullBackup  => { default => 0 },
+                           bug         => { default => 0},
+                          });
 
   my $progress = $options{progress};
   if (not $progress) {
@@ -658,14 +717,14 @@ sub makeBackup # (options)
   EBox::debug("make backup id: " . $progress->id());
   $progress->started or
     throw EBox::Exceptions::Internal("ProgressIndicator's executable has not been run");
-  
-  
+
+
   my $backupdir = backupDir();
 
   my $filename;
   try {
     $self->_modulesReady();
-    
+
     _ensureBackupdirExistence();
 
     $filename = $self->_makeBackup(%options);
@@ -680,11 +739,11 @@ sub makeBackup # (options)
   my $backupFinalPath;
   try {
       $progress->notifyTick();
-      $progress->setMessage(__('Writing backup file to hard disc'));
+      $progress->setMessage(__('Writing backup file to hard disk'));
 
-      $backupFinalPath = $self->_moveToArchives($filename, $backupdir);   
+      $backupFinalPath = $self->_moveToArchives($filename, $backupdir);
 
-      $progress->setAsFinished();   
+      $progress->setAsFinished();
   }
  otherwise {
    my $ex = shift @_;
@@ -705,8 +764,8 @@ sub _modulesReady
   foreach my $modName (@{ $global->modNames }) {
     if ($global->modIsChanged($modName)) {
       throw EBox::Exceptions::External(
-	 __('Some modules has not saved changes. Before doing the backup you must'
-	    . ' save  or discard them' ) );				      
+         __('Some modules has not saved changes. Before doing the backup you must'
+            . ' save  or discard them' ) );
     }
 }
 
@@ -725,41 +784,41 @@ sub  _moveToArchives
     throw EBox::Exceptions::Internal("Could not save the backup.");
 
   return "$backupdir/$id";
-} 
+}
 
 
 #
 # Method: makeBugReport
 #
-#   	Makes a bug report	
+#       Makes a bug report
 #
 sub makeBugReport
 {
-	my $self = shift;
-	return $self->_makeBackup(description => 'Bug report', 'bug' => 1);
+    my ($self) = @_;
+    return $self->_makeBackup(description => 'Bug report', 'bug' => 1);
 }
 
 # unpacks a backup file into a temporary directory and verifies the md5sum
 # arguments:
-# 	string: backup file
+#       string: backup file
 # returns:
-# 	string: path to the temporary directory
-sub _unpackAndVerify # (file, fullRestore) 
+#       string: path to the temporary directory
+sub _unpackAndVerify # (file, fullRestore)
 {
   my ($self, $archive, $fullRestore) = @_;
   ($archive) or throw EBox::Exceptions::External('No backup file provided.');
   my $tempdir;
 
   try {
-    # 	  unless (copy($file, "$tempdir/eboxbackup.tar")) {
-    # 	    throw EBox::Exceptions::Internal("Could not copy backup into ".
-    # 					     "the tempdir.");
-    # 	  }
+    #     unless (copy($file, "$tempdir/eboxbackup.tar")) {
+    #       throw EBox::Exceptions::Internal("Could not copy backup into ".
+    #                                        "the tempdir.");
+    #     }
 
     $tempdir = $self->_unpackArchive($archive);
 
-    unless ( -f "$tempdir/eboxbackup/files.tgz" && 
-	     -f "$tempdir/eboxbackup/md5sum") {
+    unless ( -f "$tempdir/eboxbackup/files.tgz" &&
+             -f "$tempdir/eboxbackup/md5sum") {
       throw EBox::Exceptions::External( __('Incorrect or corrupt backup file'));
     }
 
@@ -770,7 +829,7 @@ sub _unpackAndVerify # (file, fullRestore)
     my $ex = shift;
 
     if (defined $tempdir) {
-      system("rm -rf $tempdir");
+      system("rm -rf '$tempdir'");
       ($? == 0) or EBox::warning("Unable to remove $tempdir. Please do it manually");
     }
 
@@ -808,7 +867,7 @@ sub  _checkArchiveMd5Sum
 
   if ($digest ne $olddigest) {
     throw EBox::Exceptions::External(
-				     __('The backup file is corrupt.'));
+                                     __('The backup file is corrupt.'));
   }
 }
 
@@ -824,7 +883,7 @@ sub _checkArchiveType
   }
   my $type = <$TYPE_F>;
   close($TYPE_F);
-  
+
   if ($type ne all($FULL_BACKUP_ID, $CONFIGURATION_BACKUP_ID, $BUGREPORT_BACKUP_ID)) {
     throw EBox::Exceptions::External(__("The backup archive has a invalid type. Maybe the file is corrupt or you are using a incompatible eBox version"));
   }
@@ -834,7 +893,7 @@ sub _checkArchiveType
     if ($type ne $FULL_BACKUP_ID) {
       throw EBox::Exceptions::External(__('The archive does not contain a full backup, that made a full restore impossibe. A configuration recovery  may be possible'));
     }
-  } 
+  }
 
 }
 
@@ -852,12 +911,12 @@ sub  _checkSize
 
   my $tempDir;
   try {
-    $tempDir = $self->_unpackArchive($archive, 'size'); 
+    $tempDir = $self->_unpackArchive($archive, 'size');
     $size = read_file("$tempDir/eboxbackup/size"); # unit -> 1K
   }
   finally {
     if (defined $tempDir) {
-      system("rm -rf $tempDir");
+      system("rm -rf '$tempDir'");
       ($? == 0) or EBox::warning("Unable to remove $tempDir. Please do it manually");
     }
   };
@@ -870,25 +929,27 @@ sub  _checkSize
     throw EBox::Exceptions::External(__x("There in not enough space left in the hard disk to complete the restore proccess. {size} Kb required. Free sufficient space and retry", size => $size));
   }
 
-} 
+}
+
 
- 
 #
 # Method: prepareRestoreBackup
 #
-#   	Prepares a backup restauration 
+#       Prepares a backup restauration
 #
 # Parameters:
 #
-#       file - backup's file (as positional parameter) fullRestore - wether do a
-#       full restore or restore only configuration (default: false) 
-#
+#       file - backup's file (as positional parameter)
+# fullRestore - wether do a full restore or restore only configuration (default: false)
+#       dataRestore - wether do a data-only restore
+#       forceDependencies - wether ignore dependency errors between modules
+#        deleteBackup      - deletes the backup after resroting it or if the process is aborted
 #  Returns:
-#    the progress indicator object whihc represents the progress of the restauration
+#    the progress indicator object which represents the progress of the restauration
 #
 # Exceptions:
-#	
-#	External - If it can't unpack the backup archive
+#
+#       External - If it can't unpack the backup archive
 #
 sub prepareRestoreBackup
 {
@@ -910,6 +971,12 @@ sub prepareRestoreBackup
     }
   }
 
+  if (exists $options{deleteBackup}) {
+    if ($options{deleteBackup}) {
+      $execOptions .= '--delete-backup ';
+    }
+  }
+
   if (exists $options{modsToRestore}) {
     foreach my $m (@{ $options{modsToRestore} }) {
       $execOptions .= "--module $m ";
@@ -918,13 +985,13 @@ sub prepareRestoreBackup
 
 
   $restoreBackupScript    .= " $execOptions $file";
-  
+
   my $totalTicks = scalar @{ $self->_modInstancesForRestore($file) };
 
   my $progressIndicator =  EBox::ProgressIndicator->create(
-			     executable => $restoreBackupScript,
-			     totalTicks => $totalTicks,
-						    );
+                             executable => $restoreBackupScript,
+                             totalTicks => $totalTicks,
+                                                    );
 
   $progressIndicator->runExecutable();
 
@@ -933,28 +1000,31 @@ sub prepareRestoreBackup
 
 
 #
-# Method: restoreBackup 
+# Method: restoreBackup
 #
-#   	Restores a backup from file	
+#       Restores a backup from file
 #
 # Parameters:
 #
-#       file - backup's file (as positional parameter) 
+#       file - backup's file (as positional parameter)
 #       progressIndicator - Progress indicator associated
 #                       with htis operation (optional )
 # fullRestore - wether do a full restore or restore only configuration (default: false)
+#       dataRestore - wether do a data-only restore
+#       forceDependencies - wether ignore dependency errors between modules
+#        deleteBackup      - deletes the backup after resroting it or if the process is aborted
 #
 # Exceptions:
-#	
-#	External - If it can't unpack de backup
 #
-sub restoreBackup # (file, %options) 
+#       External - If it can't unpack de backup
+#
+sub restoreBackup # (file, %options)
 {
   my ($self, $file, %options) = @_;
   defined $file or throw EBox::Exceptions::MissingArgument('Backup file');
 
-  validate_with ( params => [%options], 
-		  spec => { 
+  validate_with ( params => [%options],
+		  spec => {
 			   progress    => {
 					   optional => 1,
 					   isa => 'EBox::ProgressIndicator',
@@ -964,53 +1034,54 @@ sub restoreBackup # (file, %options)
 					    optional => 1,
 					   },
 			   fullRestore => { default => 0 },
-			   dataRestore    => { 
+			   dataRestore    => {
 					   default => 0 ,
 					   # incompatible with fullRestore ..
 					   callbacks => {
-							 incompatibleRestores =>  
+							 incompatibleRestores =>
 							 sub {
 							   (not $_[0]) or (not $_[1]->{fullRestore})
 							 },
 							},
-					      
+
 					  },
 			   forceDependencies => {default => 0 },
+			   deleteBackup      => { default => 0},
 			  }
 		);
 
-  _ensureBackupdirExistence();
-  $self->_checkSize($file);
-
   my $progress = $options{progress};
   if (not $progress) {
     $progress = EBox::ProgressIndicator::Dummy->create;
     $options{progress} = $progress;
   }
 
-
-
   EBox::debug("restore backup id: " . $progress->id);
   $progress->started or
     throw EBox::Exceptions::Internal("ProgressIndicator's executable has not been run");
 
-  my $tempdir = $self->_unpackAndVerify($file, $options{fullRestore});
-
+  my $tempdir;
   try {
+    _ensureBackupdirExistence();
+
+    $self->_checkSize($file);
+
+    $tempdir = $self->_unpackAndVerify($file, $options{fullRestore});
+
     $self->_unpackModulesRestoreData($tempdir);
 
     my @modules  = @{ $self->_modInstancesForRestore($file, %options) };
     my @restored = ();
     try {
       foreach my $mod (@modules) {
-	my $restoreOk = $self->_restoreModule($mod, $tempdir, \%options);
-	if ($restoreOk) {
-	  push @restored, $mod->name();
-	}
+        my $restoreOk = $self->_restoreModule($mod, $tempdir, \%options);
+        if ($restoreOk) {
+          push @restored, $mod->name();
+        }
 
       }
 
-    } 
+    }
     otherwise {
       my $ex = shift;
 
@@ -1024,10 +1095,16 @@ sub restoreBackup # (file, %options)
     };
 
     EBox::info('Restore successful');
-    $progress->setAsFinished(); 
+    $progress->setAsFinished();
   }
   finally {
-      system 'rm -rf $tempdir';
+    if ($tempdir) {
+      system "rm -rf '$tempdir'";
+    }
+    if ($options{deleteBackup}) {
+      unlink $file;
+    }
+
   };
 }
 
@@ -1036,15 +1113,15 @@ sub _unpackModulesRestoreData
 {
   my ($self, $tempdir) = @_;
 
-  my $unpackCmd = "tar xzf $tempdir/eboxbackup/files.tgz -C $tempdir/eboxbackup";
+  my $unpackCmd = "tar xzf '$tempdir/eboxbackup/files.tgz' -C '$tempdir/eboxbackup'";
 
   system $unpackCmd;
 
   if ($? != 0) {
-    system 'rm -rf $tempdir';
+    system "rm -rf '$tempdir'";
     throw EBox::Exceptions::External(
-				     __('Could not unpack the backup')
-				    );
+                                     __('Could not unpack the backup')
+                                    );
   }
 }
 
@@ -1053,9 +1130,9 @@ sub _restoreModule
   my ($self, $mod, $tempdir, $options_r) = @_;
   my $modname = $mod->name();
 
-  # update progress indicator 
+  # update progress indicator
   my $progress = $options_r->{progress};
-  $progress->notifyTick(); 
+  $progress->notifyTick();
   $progress->setMessage($modname);
 
   if (not -e "$tempdir/eboxbackup/$modname.bak") {
@@ -1067,13 +1144,13 @@ sub _restoreModule
   $mod->setAsChanged(); # we set as changed first because it is not
   # guaranteed that a failed backup will not
   # change state
-  $mod->restoreBackup("$tempdir/eboxbackup", 
-		      fullRestore => $options_r->{fullRestore},
-		      dataRestore => $options_r->{dataRestore},
-		     );
+  $mod->restoreBackup("$tempdir/eboxbackup",
+                      fullRestore => $options_r->{fullRestore},
+                      dataRestore => $options_r->{dataRestore},
+                     );
 
   $self->_migratePackage($mod->package());
-  
+
   return 1;
 }
 
@@ -1098,17 +1175,17 @@ sub _revokeRestore
 
 sub _migratePackage
 {
-	my ($self, $package) = @_;
-	my $migrationdir = EBox::Config::share() . "/$package/migration";
-	
-	if (-d $migrationdir) {
-		my $migration = EBox::Config::pkgdata() . '/ebox-migrate';
-		try {
-			EBox::Sudo::command("$migration $migrationdir");
-		} catch EBox::Exceptions::Internal with {
-			EBox::debug("Failed to migrate $package");
-		};
-	}
+    my ($self, $package) = @_;
+    my $migrationdir = EBox::Config::share() . "/$package/migration";
+
+    if (-d $migrationdir) {
+        my $migration = EBox::Config::pkgdata() . '/ebox-migrate';
+        try {
+            EBox::Sudo::command("$migration $migrationdir");
+        } catch EBox::Exceptions::Internal with {
+            EBox::debug("Failed to migrate $package");
+        };
+    }
 }
 
 
@@ -1128,12 +1205,12 @@ sub _modInstancesForRestore
     my @modsToRestore =  @{ $options{modsToRestore} };
     foreach my $m (@modsToRestore) {
       if (not( $m eq $anyModuleInBackup)) {
-	throw EBox::Exceptions::External(
-					 __x(
-					     'No module {m} found in backup',
-					     'm' => $m
-					    )
-					);
+        throw EBox::Exceptions::External(
+                                         __x(
+                                             'No module {m} found in backup',
+                                             'm' => $m
+                                            )
+                                        );
       }
     }
 
@@ -1153,14 +1230,12 @@ sub _modInstancesForRestore
 
 
   # we remove global module because it will not  be restored
-  @modules   =  grep { $_->name ne 'global' } @modules;   
-  # XXX temporally skipping log module
-  @modules = grep {  $_->name ne 'logs' } @modules;
+  @modules   =  grep { $_->name ne 'global' } @modules;
 
   if (not @modules) {
     throw EBox::Exceptions::External(
-	      __('No modules to restore')
-				    );
+              __('No modules to restore')
+                                    );
   }
 
 
@@ -1169,7 +1244,7 @@ sub _modInstancesForRestore
     foreach my $mod (@modules) {
       $self->_checkModDeps($mod->name);
     }
-    
+
   }
 
   # we sort the modules list with a restore-safe order
@@ -1195,8 +1270,8 @@ sub _modulesInBackup
 {
   my ($self, $archive) = @_;
 
-  my $tempDir = $self->_unpackArchive($archive, 'modules'); 
-  my $modulesString = read_file("$tempDir/eboxbackup/modules"); 
+  my $tempDir = $self->_unpackArchive($archive, 'modules');
+  my $modulesString = read_file("$tempDir/eboxbackup/modules");
 
   my @modules = split '\s', $modulesString;
   return \@modules;
@@ -1211,7 +1286,7 @@ sub _checkModDeps
   if ($level == 0) {
     $topModule = $modName;
   }
- 
+
   if ($level >= $RECURSIVE_DEPENDENCY_THRESHOLD) {
     throw EBox::Exceptions::Internal('Recursive restore dependency found.');
   }
@@ -1242,11 +1317,11 @@ sub _checkModDeps
 
 sub _checkId
 {
-  my ($self, $id) = @_;  
+  my ($self, $id) = @_;
   if ($id =~ m{[./]}) {
-		throw EBox::Exceptions::External(
-			__("The input contains invalid characters"));
-	}
+                throw EBox::Exceptions::External(
+                        __("The input contains invalid characters"));
+        }
 }
 
 sub _backupFileById
@@ -1256,7 +1331,7 @@ sub _backupFileById
     my $backupdir = EBox::Config::conf . '/backups';
     my $file = "$backupdir/$id.tar";
     unless (-f $file) {
-	throw EBox::Exceptions::External("Could not find the backup.");
+        throw EBox::Exceptions::External("Could not find the backup.");
     }
 
     return $file;
@@ -1267,8 +1342,8 @@ sub _backupFileById
 sub _facilitiesForDiskUsage
 {
   return {
-	  __(q{Backup's archives}) => [ backupDir() ],
-	 }
+          __(q{Backup's archives}) => [ backupDir() ],
+         }
 }
 
 1;
