@@ -42,10 +42,15 @@ sub new # (title=?, error=?, msg=?, cgi=?, template=?)
 	my %opts = @_;
 
 	my $self = $class->SUPER::new(@_);
+    my $namespace = delete $opts{'namespace'};
 	my $tmp = $class;
-	$tmp =~ s/^.*?::.*?::(.*?)::(.*)//;
-	$self->{module} = $1;
-	$self->{cginame} = $2;
+    $tmp =~ s/^(.*?)::CGI::(.*?)(?:::)?(.*)//;
+    if(not $namespace) {
+        $namespace = $1;
+    }
+    $self->{namespace} = $namespace;
+	$self->{module} = $2;
+	$self->{cginame} = $3;
 	if (defined($self->{cginame})) {
 		$self->{url} = $self->{module} . "/" . $self->{cginame};
 	} else {
@@ -96,7 +101,7 @@ sub _print_error
 	my $r = Apache2::RequestUtil->request();
 	my $filename = EBox::Config::templates . '/error.mas';
 	my $output;
-	my $interp = HTML::Mason::Interp->new(comp_root => 
+	my $interp = HTML::Mason::Interp->new(comp_root =>
 						EBox::Config::templates,
 						out_method => \$output);
 	my $comp = $interp->make_component(comp_file => $filename);
@@ -115,17 +120,17 @@ sub _print_warning
 	$text or return;
 	($text ne "") or return;
 
-	# We send a WARNING_STATUS code. 
+	# We send a WARNING_STATUS code.
 	my $r = Apache2::RequestUtil->request();
 	$r->status(DATA_IN_USE_STATUS);
 	$r->custom_response(DATA_IN_USE_STATUS, "");
 
 	my $filename = EBox::Config::templates . '/dataInUse.mas';
 	my $output;
-	my $interp = HTML::Mason::Interp->new(comp_root => 
+	my $interp = HTML::Mason::Interp->new(comp_root =>
 						EBox::Config::templates,
 						out_method => \$output);
-					
+
 	my $comp = $interp->make_component(comp_file => $filename);
 	my @params = ();
 	push(@params, 'warning' => $text);
@@ -160,46 +165,49 @@ sub run
 	if (not $self->_loggedIn) {
 		$self->{redirect} = "/ebox/Login/Index";
 	}
-	else { 
+	else {
 	  try {
 	    settextdomain($self->domain());
 	    $self->_process();
+	 } catch EBox::Exceptions::DataInUse with {
+	  	my $e = shift;
+		$self->_print_warning($e->text());
+		$finish = 1;
+	  } catch EBox::Exceptions::Internal with {
 
+	  	my $e = shift;
+		throw $e;
 	  } catch EBox::Exceptions::DataInUse with {
 	  	my $e = shift;
 		$self->_print_warning($e->text());
 		$finish = 1;
 	  } catch EBox::Exceptions::Base with {
 		  my $e = shift;
-		  $self->setErrorFromException($e);	 
+		  $self->setErrorFromException($e);
 		  $self->_error();
 	  	  $finish = 1;
 	  } otherwise {
 		  my $e = shift;
-		  $self->setErrorFromException($e);	 
-		  $self->_error();
-		  $finish = 1;
+		  throw $e;
 	  };
 	}
-	
+
 	return if ($finish == 1);
 
-	try  { 
+	try  {
 	  settextdomain('ebox');
-	  $self->_print 
+	  $self->_print
 	} catch EBox::Exceptions::Internal with {
-	  my $error = __("An internal error has ocurred. " . 
-			 "This is most probably a bug, relevant ". 
-			 "information can be found in the logs.");
-	  $self->_print_error($error);
-	} 
+	  my $ex = shift;
+	  $self->_print_error($ex->stacktrace());
+	}
 	otherwise {
 	    my $ex = shift;
 	    my $logger = EBox::logger;
 	    if (isa_mason_exception($ex)) {
 	      $logger->error($ex->as_text);
 	      my $error = __("An internal error related to ".
-			     "a template has occurred. This is ". 
+			     "a template has occurred. This is ".
 			     "a bug, relevant information can ".
 			     "be found in the logs.");
 	      $self->_print_error($error);
@@ -207,7 +215,7 @@ sub run
 	      if ($ex->can('text')) {
 		$logger->error('Exception: ' . $ex->text());
 	      } else {
-		$logger->error("Unknown exception");			    
+		$logger->error("Unknown exception");
 	      }
 
 	      throw $ex;
