@@ -24,31 +24,33 @@ use EBox;
 use EBox::Gettext;
 use EBox::Global;
 use EBox::Model::ModelManager;
+use EBox::Html;
 use POSIX qw(ceil);
 
 use constant PAGESIZE => 15;
 
 sub new # (error=?, msg=?, cgi=?)
 {
-	my $class = shift;
-	my $self = $class->SUPER::new('title' => __('Logs'),
-				      'template' => '/logs/index.mas',
-				      @_);
-	$self->{domain} = 'ebox';
-	bless($self, $class);
-	return $self;
+    my $class = shift;
+    my $self = $class->SUPER::new('title' => __('Logs'),
+                                  'template' => '/logs/index.mas',
+                                  @_);
+    $self->{domain} = 'ebox';
+    bless($self, $class);
+    return $self;
 }
 
-sub _getTime {
-	my ($self, $module, $tmpl) = @_;
+sub _getTime
+{
+    my ($self, $module, $tmpl) = @_;
 
-	foreach my $mod (@{$tmpl}) {
-		if ($mod->{'name'} eq $module) {
-			return $mod->{'timecol'};
-		}
-	}
+    foreach my $mod (@{$tmpl}) {
+        if ($mod->{'name'} eq $module) {
+            return $mod->{'timecol'};
+        }
+    }
 
-	return undef;
+    return undef;
 }
 
 
@@ -57,26 +59,26 @@ sub _actualPage
     my ($self, $tpages) = @_;
 
     my $page = $self->param('page');
-    
+
     unless (defined($self->param('page'))) {
-	$page = 0;
+        $page = 0;
     }
 
-    if(defined($self->param('tofirst'))) { 
-	$page = 0; 
+    if (defined($self->param('tofirst'))) {
+        $page = 0;
     }
-    if(defined($self->param('toprev'))) { 
-	if ($page > 0) { 
-	    $page = $page -1; 
-	} 
+    if (defined($self->param('toprev'))) {
+        if ($page > 0) {
+            $page = $page -1;
+        }
     }
-    if(defined($self->param('tonext'))) { 
-	if ($page < $tpages) {
-	    $page = $page + 1; 
-	}
+    if (defined($self->param('tonext'))) {
+        if ($page < $tpages) {
+            $page = $page + 1;
+        }
     }
-    if(defined($self->param('tolast'))) { 
-	$page = $tpages; 
+    if (defined($self->param('tolast'))) {
+        $page = $tpages;
     }
 
     return $page;
@@ -91,12 +93,12 @@ sub addToMasonParameters
     defined $self->{params} or $self->{params} = [];
     my $oldParams_r= $self->{params};
     if (defined $oldParams_r) {
-	push @masonParams, @{ $oldParams_r };
+        push @masonParams, @{ $oldParams_r };
     }
 
 
-    
-    
+
+
     $self->{params}  = \@masonParams;
 }
 
@@ -113,7 +115,18 @@ sub _fromDate
 sub _toDate
 {
     my ($self) = @_;
-    my $toDate = $self->_getDateArray('to');
+
+    my $toDate;
+    my $refresh = $self->refresh();
+
+    if ($refresh) {
+        # 86400 second -> one day
+        $toDate = $self->_getDateArray('to', 86400, 0);
+    }
+    else {
+        $toDate = $self->_getDateArray('to');
+    }
+
 
     return $toDate;
 }
@@ -121,8 +134,9 @@ sub _toDate
 
 sub _getDateArray
 {
-    my ($self, $prefix, $defaultTimeAdjust) = @_;
+    my ($self, $prefix, $defaultTimeAdjust, $useParamsValue) = @_;
     defined $defaultTimeAdjust or $defaultTimeAdjust = 0;
+    defined $useParamsValue    or $useParamsValue    = 1;
 
     my %time;
 
@@ -133,12 +147,16 @@ sub _getDateArray
     $time{$prefix . 'day'}   = $localtime[3];
     $time{$prefix . 'month'} = $localtime[4] + 1;
     $time{$prefix . 'year'}  = $localtime[5]  + 1900;
-    
-    foreach my $key (keys %time) {
-	my $paramValue = $self->param($key);
-	if (defined $paramValue) {
-	    $time{$key} = $paramValue;
-	}
+
+
+    if ($useParamsValue) {
+        foreach my $key (keys %time) {
+            my $paramValue = $self->param($key);
+            if (defined $paramValue) {
+                $time{$key} = $paramValue;
+            }
+        }
+
     }
 
     my @wantedOrder = map { $prefix . $_  }  qw(day month year hour min sec) ;
@@ -160,19 +178,19 @@ sub _searchLogs
 
     my $tpages = ceil($logs->totalRecords($table) / PAGESIZE) - 1;
     my $page = $self->_actualPage($tpages);
-    
+
     my @fromdate = @{ $self->_fromDate() };
     my @todate   = @{ $self->_toDate() };
 
     $hfilters = $self->_paramFilters();
     %hret = %{$logs->search($fromdate[2].'-'.$fromdate[1].'-'.$fromdate[0].' '.$fromdate[3].':'.$fromdate[4].':0',
-			    $todate[2].'-'.$todate[1].'-'.$todate[0].' '.$todate[3].':'.$todate[4].':0',
-			    $selected, 
-			    PAGESIZE,
-			    $page,
-			    $timecol,
-			    $hfilters)};
-    
+                            $todate[2].'-'.$todate[1].'-'.$todate[0].' '.$todate[3].':'.$todate[4].':0',
+                            $selected,
+                            PAGESIZE,
+                            $page,
+                            $timecol,
+                            $hfilters)};
+
     $tpages = ceil ($hret{'totalret'} / PAGESIZE) -1;
     $page = $self->_actualPage($tpages);
 
@@ -185,18 +203,18 @@ sub _searchLogs
     push(@masonParameters, 'data' => $hret{'arrayret'});
     push(@masonParameters, 'fromdate' => \@fromdate);
     push(@masonParameters, 'todate' => \@todate);
-	
+
     $self->addToMasonParameters(@masonParameters);
 
 }
 
 sub _encode_filters {
-	my ($par) = @_;
+        my ($par) = @_;
 
-	my %encoded = map { $par->{$_} =~ s/'/&#39;/g; $_ => $par->{$_}  } 
-			keys %{$par};
-	
-	return \%encoded;
+        my %encoded = map { $par->{$_} =~ s/'/&#39;/g; $_ => $par->{$_}  }
+                        keys %{$par};
+
+        return \%encoded;
 }
 
 # Method called when the user may want to save the query as an event
@@ -209,6 +227,7 @@ sub _saveAsEvent
     my $hfilters = $self->_paramFilters();
     my $selected = $self->param('selected');
 
+    # TODO Use new row/ids API
     my $manager = EBox::Model::ModelManager->instance();
     my $logConfModel = $manager->model('/events/LogWatcherConfiguration');
     my $loggerConfRow = $logConfModel->findValue(domain => $selected);
@@ -239,39 +258,93 @@ sub _paramFilters
 
     my $hfilters = {};
     foreach my $filter (grep(s/^filter-//, @{$self->params()})) {
-	$hfilters->{$filter} =
+        $hfilters->{$filter} =
           $self->unsafeParam("filter-$filter");
     }
     return $hfilters;
 
 }
 
-sub _process
+
+sub _header
 {
-	my ($self) = @_;
+    my ($self) = @_;
 
-	my $logs = EBox::Global->modInstance('logs');
+    if (not $self->refresh()) {
+        $self->SUPER::_header();
+        return;
+    }
 
-        # The user may click on saveAsEvent
-        if ( $self->param('saveAsEvent') ) {
-            $self->_saveAsEvent();
-            return;
+
+    my $destination = "/ebox/Logs/Index?";
+
+    my %params = %{ $self->paramsAsHash() };
+    $params{refresh} = 1; # to assure the refresh parameter is active
+
+    while (my ($param, $value) = each %params) {
+        if ($param eq 'View') {
+            # View we want to only use it the first time to set default refresh
+            # as 1
+            next;
         }
 
-	my $selected = $self->param('selected');
+        $destination .= "$param=$value&";
+    }
+    $destination =~ s/&$//;
 
-	if (defined($selected)) {
-	    $self->_searchLogs($logs, $selected);
-	} 
-	else {
-		$selected = 'none';
-	}
 
-	my @masonParameters;
-	push(@masonParameters, 'logdomains' => $logs->getLogDomains());
-	push(@masonParameters, 'selected' => $selected);
+    print($self->cgi()->header(-charset=>'utf-8'));
+    my $html = EBox::Html::makeHtml(
+                                     'headerWithRefresh.mas',
+                                     title => $self->{title},
+                                     destination => $destination
+                                    );
+    print $html;
+}
 
-	$self->addToMasonParameters(@masonParameters);
+
+
+sub refresh
+{
+    my ($self) = @_;
+
+    return 1 if $self->param('refresh');
+    return 1 if $self->param('View');
+
+
+    return 0;
+}
+
+
+sub _process
+{
+    my ($self) = @_;
+
+    my $logs = EBox::Global->modInstance('logs');
+
+    # The user may click on saveAsEvent
+    if ( $self->param('saveAsEvent') ) {
+        $self->_saveAsEvent();
+        return;
+    }
+
+    my $selected = $self->param('selected');
+
+    if (defined($selected)) {
+        $self->_searchLogs($logs, $selected);
+    } else {
+        $selected = 'none';
+    }
+
+    my @masonParameters;
+    push(@masonParameters, 'logdomains' => $logs->getLogDomains());
+    push(@masonParameters, 'selected' => $selected);
+
+
+    push(@masonParameters, refresh => $self->refresh);
+
+
+    $self->addToMasonParameters(@masonParameters);
 }
 
 
