@@ -24,10 +24,9 @@ package EBox::Events;
 #      since it may be considered as a base module as logs. It manages
 #      the EventDaemon.
 
-use base qw(EBox::GConfModule 
-            EBox::Model::ModelProvider 
+use base qw(EBox::Module::Service
+            EBox::Model::ModelProvider
             EBox::Model::CompositeProvider
-			EBox::ServiceModule::ServiceInterface
             );
 
 use strict;
@@ -45,7 +44,6 @@ use EBox::Global;
 use EBox::Menu::Folder;
 use EBox::Menu::Item;
 use EBox::Service;
-use EBox::Summary::Status;
 
 # Core modules
 use Error qw(:try);
@@ -75,7 +73,7 @@ use constant CONF_WATCHER_MODEL_PREFIX => 'EBox::Events::Model::Watcher::';
 #
 # Overrides:
 #
-#        <EBox::GConfModule::_create>
+#        <EBox::Module::Service::_create>
 #
 # Returns:
 #
@@ -88,7 +86,7 @@ sub _create
 
       my $self = $class->SUPER::_create( name => 'events',
                                          domain => 'ebox-events',
-                                         printableName => __('events'),
+                                         printableName => __('Events'),
                                          @_
                                        );
 
@@ -98,62 +96,39 @@ sub _create
 
   }
 
-#  Method: serviceModuleName
-#
-#   Override EBox::ServiceModule::ServiceInterface::servivceModuleName
-#
-sub serviceModuleName
+sub _daemons
 {
-	return 'events';
+    return [ { 'name' => SERVICE } ];
 }
 
-
-# Method: _regenConfig
+# Method: _setConf
 #
-#        Regenerate the configuration for the events
+#   Regenerate the configuration for the events
 #
 # Overrides:
 #
-#       <EBox::Module::_regenConfig>
+#       <EBox::Module::Base::_setConf>
 #
-# Exceptions:
-#
-#       <EBox::Exceptions::External> - if no event watcher and event
-#       dispatcher are enabled
-#
-sub _regenConfig
-  {
+sub _setConf
+{
+    my ($self) = @_;
 
-      my ($self) = @_;
+    # Do the movements to make EventDaemon notice to work
+    unless ($self->isReadOnly()) {
+        $self->_submitEventElements();
+    }
+}
 
-      unless ( $self->isReadOnly() ) {
-          # Do the movements to make EventDaemon notice to work
-          $self->_submitEventElements();
-      }
+sub _enforceServiceState {
+    my ($self) = @_;
 
-      # Check for admin dumbness, it can throw an exception
-      if ( $self->_adminDumbness() ) {
-          $self->_stopService();
-          return;
-      }
-
-      $self->_doDaemon();
-
-  }
-
-# Method: _stopService
-#
-#        Stop the event service
-# Overrides:
-#
-#       <EBox::Module::_stopService>
-#
-sub _stopService
-  {
-
-      EBox::Service::manage(SERVICE, 'stop');
-
-  }
+    # Check for admin dumbness, it can throw an exception
+    if ($self->_adminDumbness()) {
+        $self->_stopService();
+        return;
+    }
+    $self->SUPER::_enforceServiceState();
+}
 
 # Group: Public methods
 
@@ -171,36 +146,15 @@ sub menu
       my ($self, $root) = @_;
 
       my $item = new EBox::Menu::Item(name  => 'Events',
-                                      text  => __('Events'),
+                                      text  => $self->printableName(),
                                       url   => 'Events/Composite/GeneralComposite',
-                                      order => 7);
+                                      separator => __('Core'),
+                                      order => 90);
 
       $root->add($item);
 
   }
 
-# Method: statusSummary
-#
-#       Show the event status summary
-#
-# Overrides:
-#
-#       <EBox::Module::statusSummary>
-#
-sub statusSummary
-  {
-
-      my ($self) = @_;
-
-      return new EBox::Summary::Status(
-                                       'events',
-                                       __('Events'),
-                                       $self->running(),
-                                       $self->service(),
-                                      );
-
-  }
-
 # Method: models
 #
 #       Return the models used by events eBox module
@@ -324,7 +278,7 @@ sub configureDispatcherModel
 
       # Check if it is already cached
       unless ( exists $self->{configureDispatcherModel} ) {
-          $self->{configureDispatcherModel} = 
+          $self->{configureDispatcherModel} =
             new EBox::Events::Model::ConfigureDispatcherDataTable(
                  gconfmodule => $self,
                  directory   => 'configureDispatcherTable'
@@ -335,53 +289,17 @@ sub configureDispatcherModel
 
   }
 
-# Method: running
+# Method: isRunning
 #
-#      Request to know if the event daemon is running or not
+# Overrides:
 #
-# Returns:
+#      <EBox::Module::Service::isRunning>
 #
-#      boolean - the event daemon is running or not
-#
-sub running
-  {
-
-      return EBox::Service::running(SERVICE);
-
-  }
-
-# Method: service
-#
-#      Check whether the Events service is enabled or not
-#
-# Returns:
-#
-#      boolean - the service is enabled or not
-#
-sub service
-  {
-
-      my ($self) = @_;
-
-	  return $self->isEnabled();
-
-  }
-
-# Method: setService
-#
-#      Set if the events service is enabled or not
-#
-# Parameters:
-#
-#      enabled - boolean service to be enabled or not
-#
-sub setService
-  {
-
-      my ($self, $enabled) = @_;
-      
-      $self->enableService($enabled);
-  }
+sub isRunning
+{
+    my ($self) = @_;
+    return $self->isEnabled();
+}
 
 # Method: enableEventElement
 #
@@ -444,21 +362,6 @@ sub enableEventElement # ($className, $enabled)
 
 # Group: Private methods
 
-sub _doDaemon
-  {
-
-      my ($self) = @_;
-
-      if ( $self->running() and $self->service() ) {
-          EBox::Service::manage(SERVICE, 'restart');
-      } elsif ( $self->service() ) {
-          EBox::Service::manage(SERVICE, 'start');
-      } else {
-          EBox::Service::manage(SERVICE, 'stop');
-      }
-
-  }
-
 # Check if at least one watcher and one dispatcher are enabled
 sub _adminDumbness
   {
@@ -490,15 +393,15 @@ sub _prepareRestoreBackup
     my ($self) = @_;
 
     my $eventModel = $self->configureEventModel();
-    my @enableEvents =  map { $_->{'eventWatcher'} } 
+    my @enableEvents =  map { $eventModel->row($_)->valueByName('eventWatcher') }
     @{$eventModel->findAllValue (enabled => 1)};
-    my @disableEvents =  map { $_->{'eventWatcher'} } 
+    my @disableEvents =  map { $eventModel->row($_)->valueByName('eventWatcher') }
     @{$eventModel->findAllValue (enabled => 0)};
 
     my $dispatcherModel = $self->configureDispatcherModel();
-    my @enableDispatchers =  map { $_->{'eventDispatcher'} } 
+    my @enableDispatchers =  map { $dispatcherModel->row($_)->valueByName('eventDispatcher') }
     @{$dispatcherModel->findAllValue (enabled => 1)};
-    my @disableDispatchers =  map { $_->{'eventDispatcher'} } 
+    my @disableDispatchers =  map { $dispatcherModel->row($_)->valueByName('eventDispatcher') }
     @{$dispatcherModel->findAllValue (enabled => 0)};
 
     $self->set_list('watcher_to_enable', 'string', \@enableEvents);
