@@ -43,6 +43,8 @@ use EBox::Types::Text;
 use EBox::Types::Union;
 use EBox::Types::Union::Text;
 
+use Error qw(:try);
+
 # Constants:
 #
 #      DISPATCHER_DIR - String directory where the Dispatchers are
@@ -95,7 +97,7 @@ sub new
 #
 #   string
 #
-sub headTitle 
+sub headTitle
 {
 
     my ($self) = @_;
@@ -103,7 +105,7 @@ sub headTitle
     return undef;
 }
 
-# Method: rows
+# Method: syncRows
 #
 #      This method is overridden since the showed data is managed
 #      differently.
@@ -118,46 +120,69 @@ sub headTitle
 #
 # Overrides:
 #
-#        <EBox::Model::DataTable::rows>
+#        <EBox::Model::DataTable::syncRows>
 #
-sub rows
+sub syncRows
   {
 
-      my ($self, $filter, $page) = @_;
+      my ($self, $currentIds) = @_;
 
       # If the GConf module is readonly, return current rows
       if ( $self->{'gconfmodule'}->isReadOnly() ) {
-          return $self->SUPER::rows($filter, $page);
+          return undef;
       }
 
-      # Fetch the current event watchers from gconf
-      my $currentRows = $self->SUPER::rows();
+      my $modIsChanged = EBox::Global->getInstance()->modIsChanged('events');
 
       my %storedEventDispatchers;
-      foreach my $currentRow (@{$currentRows}) {
-          $storedEventDispatchers{$currentRow->valueByName('eventDispatcher')} = 'true';
-      }
-
       my %currentEventDispatchers;
       my $dispatchersRef = $self->_fetchDispatchers();
       foreach my $dispatcherFetched (@{$dispatchersRef}) {
           $currentEventDispatchers{$dispatcherFetched} = 'true';
       }
 
+      my $modified = undef;
+
+      # Removing old ones
+      foreach my $id (@{$currentIds}) {
+          my $row;
+          my $removed = 0;
+          try {
+              $row = $self->row($id);
+          } catch EBox::Exceptions::Base with {
+              $self->removeRow( $id );
+              $modified = 1;
+              $removed = 1;
+          };
+          next if ($removed);
+          my $stored = $row->valueByName('eventDispatcher');
+          $storedEventDispatchers{$stored} = 'true';
+          next if ( exists ( $currentEventDispatchers{$stored} ));
+          $self->removeRow( $id );
+          $modified = 1;
+      }
+
       # Adding new ones
       foreach my $dispatcher (keys ( %currentEventDispatchers )) {
           next if ( exists ( $storedEventDispatchers{$dispatcher} ));
           # Create a new instance from this dispatcher
           eval "use $dispatcher";
-
+          my $enabled = ! $dispatcher->DisabledByDefault();
+          # XXX Enable Log dispatcher by default and not allow user
+          # to disable it
+          if ( $enabled ) {
+              $self->{'gconfmodule'}->enableEventElement('dispatcher', 
+                $dispatcher, 1);
+          }
           my %params = (
                         'eventDispatcher'        => $dispatcher,
                         # The value is obtained dynamically
                         'receiver'               => '',
-                        # The events are disabled by default
-                        'enabled'                => 0,
+                        # The dispatchers are disabled by default
+                        'enabled'                => $enabled,
                         'configuration_selected' => 'configuration_' .
                                                     $dispatcher->ConfigurationMethod(),
+                        'readOnly'               => not $dispatcher->EditableByUser(),
                        );
 
           if ( $dispatcher->ConfigurationMethod() eq 'none') {
@@ -165,17 +190,15 @@ sub rows
           }
 
           $self->addRow(%params);
+          $modified = 1;
       }
 
-      # Removing old ones
-      foreach my $row (@{$currentRows}) {
-          my $stored = $row->valueByName('eventDispatcher');
-          next if ( exists ( $currentEventDispatchers{$stored} ));
-          $self->removeRow( $row->id() );
+      if ($modified and not $modIsChanged) {
+          $self->{'gconfmodule'}->_saveConfig();
+          EBox::Global->getInstance()->modRestarted('events');
       }
 
-      return $self->SUPER::rows($filter, $page);
-
+      return $modified;
   }
 
 # Method: updatedRowNotify
@@ -200,10 +223,12 @@ sub updatedRowNotify
 
       # Get whether the event watcher is enabled or not
       my $newRow = $self->row($rowRef->id());
-      my $enabled = $newRow->valueByName('enabled');
+      my $enabled = $rowRef->valueByName('enabled');
       my $className = $newRow->valueByName('eventDispatcher');
 
       # Set to move
+      use Data::Dumper;
+      EBox::debug("$className to $enabled");
       $self->{gconfmodule}->enableEventElement('dispatcher', $className, $enabled);
 
   }
@@ -306,7 +331,7 @@ sub _table
                                 ]
                                ),
          new EBox::Types::Boolean(
-                                  fieldName     => 'enabled', 
+                                  fieldName     => 'enabled',
                                   printableName => __('Enabled'),
                                   class         => 'tcenter',
                                   type          => 'boolean',
@@ -324,7 +349,7 @@ sub _table
       my $dataTable =
         {
          tableName          => 'ConfigureDispatcherDataTable',
-         printableTableName => __('Configure dispatchers'),
+         printableTableName => __('Configure Dispatchers'),
          actions => {
                      editField  => '/ebox/Events/Controller/ConfigureDispatcherDataTable',
                      changeView => '/ebox/Events/Controller/ConfigureDispatcherDataTable',
@@ -455,12 +480,13 @@ sub acquireConfModel
 
       my ($row) = @_;
 
-      my $className = $row->{eventDispatcher};
+      my $className = $row->valueByName('eventDispatcher');
 
       eval "use $className";
       if ( $@ ) {
           # Error loading class -> dispatcher to remove
-          throw EBox::Exceptions::Internal("Class $className does not compile: $@");
+          # Setting the fallback model
+          return 'Fallback';
       }
 
       return $className->ConfigureModel();
