@@ -88,6 +88,11 @@ sub new
       my $description = $self->_description();
       $self->_setDescription($description);
 
+      # gconfdirectory mut not be null
+      if (not exists $self->{gconfdir}) {
+          $self->{gconfdir} = '';
+      }
+
       return $self;
 
   }
@@ -104,7 +109,6 @@ sub new
 #
 sub components
   {
-
       my ($self) = @_;
 
       for (my $idx = 0; $idx < scalar (@{$self->{components}}); $idx++) {
@@ -119,10 +123,11 @@ sub components
                                                       );
               }
               if ( ref ( $component ) eq 'ARRAY' ) {
+
                   # More than one component to store in
                   my @remainder = ();
                   if ( $idx + 1 <= $#{$self->{components}} ) {
-                      @remainder = $self->{components}->[$idx + 1 .. $#{$self->{components}}];
+                     @remainder = $self->{components}->[$idx + 1 .. $#{$self->{components}}];
                       # Remove remainder elements
                       $self->{components}->[$idx .. $#{$self->{components}}] = ();
                   } else {
@@ -141,6 +146,9 @@ sub components
 
   }
 
+
+
+
 # Method: addComponent
 #
 #      Add a component to the composite. It must be a class of
@@ -192,8 +200,10 @@ sub addComponent
 
     push ( @{$self->{components}}, $component );
 
-    return;
 
+    $component->setParentComposite($component);
+
+    return;
 }
 
 # Method: delComponent
@@ -284,6 +294,45 @@ sub delComponent
 
 }
 
+
+#  Method: componentByName
+#
+#     get a specific component from the composite
+#
+#  Parameters:
+#    name - the name of the component to fetch
+#    recursive - searchs inside the components (default: false)
+#
+#  Returns:
+#    the component or undef if there is not any component with the given name
+sub componentByName
+{
+    my ($self, $name, $recursive) = @_;
+    $name or
+        throw EBox::Exceptions::MissingArgument('name');
+
+    my $components = $self->components();
+    foreach my $comp (@{ $components }) {
+        if ($name eq $comp->name()) {
+            return $comp;
+        }
+
+        if ($recursive) {
+            if ($comp->can('componentByName')) {
+                my $compFromChild;
+                $compFromChild = $comp->componentByName($name, 1);
+                if (defined $compFromChild) {
+                    return $compFromChild;
+                }
+            }
+        }
+
+    }
+
+    return undef;
+}
+
+
 # Method: setLayout
 #
 #      Set the layout where the elements will be displayed.
@@ -352,10 +401,8 @@ sub layout
 # Returns:
 #
 #      String - the composite's name
-#
 sub name
 {
-
     my ($self) = @_;
 
     return $self->{name};
@@ -397,7 +444,7 @@ sub nameFromClass
   else {
     $class = $self;
   }
-  
+
 
   my @parts = split '::', $class;
   my $name = pop @parts;
@@ -430,7 +477,7 @@ sub printableName
 #
 #   string
 #
-sub pageTitle 
+sub pageTitle
   {
 
       my ($self) = @_;
@@ -815,14 +862,13 @@ sub _setDescription
 #    <EBox::Model::DataTable>
 #
 sub _lookupComponent
-  {
-
+{
       my ($self, $componentName) = @_;
 
       my $components;
 
-      my $compManager = EBox::Model::CompositeManager->Instance();
       try {
+          my $compManager = EBox::Model::CompositeManager->Instance();
           $components = $compManager->composite($componentName);
       } catch EBox::Exceptions::DataNotFound with {
           # Look up the model manager
@@ -834,12 +880,26 @@ sub _lookupComponent
               my $modelManager = EBox::Model::ModelManager->instance();
               $components = $modelManager->model($componentName);
           } catch EBox::Exceptions::DataNotFound with {
-              $components = undef;
-          };
+             $components = undef;
+         };
+      }
+
+      if (not defined $components) {
+          return undef;
+      }
+
+      # set directories and parentComposite
+      if (ref $components eq 'ARRAY') {
+          foreach my $comp (@{ $components }) {
+              $self->setComponentDirectory($comp);
+              $comp->setParentComposite($self);
+          }
+      } else {
+          $self->setComponentDirectory($components);
+          $components->setParentComposite($self);
       }
 
       return $components;
-
   }
 
 # Method: _setDefaultActions
@@ -876,4 +936,185 @@ sub _setDefaultActions
 
   }
 
+
+sub keywords
+{
+    my ($self) = @_;
+    #get the keywords from every component plus own ones and flatten them into
+    #an array
+    return [@{$self->SUPER::keywords()}, map { @{$_->keywords()} } @{$self->components()}];
+}
+
+
+
+# XXX seemes neccesary
+# Method: setDirectory
+#
+#    Use this method to set the current directory. This method
+#    comes in handy to manage several tables with same model
+#
+# Parameters:
+#
+#     directory - string containing the name
+#
+sub setDirectory
+{
+    my ($self, $dir) = @_;
+
+    unless (defined $dir) {
+        throw EBox::Exceptions::MissingArgument('dir');
+    }
+
+    $self->{'gconfdir'} = $dir;
+
+    if (not $self->precondition()) {
+        # we dont bother to initialize components bz their wont be displayed
+        # moreover some variable components may not be able to initialize if the
+        # precondition fails
+        return;
+    }
+
+
+    foreach my $component (@{ $self->components() }) {
+        $self->setComponentDirectory($component);
+    }
+
+}
+
+
+# Method: directory
+#
+#        Get the current directory.
+#
+# Returns:
+#
+#        String - Containing the directory
+#
+sub directory
+  {
+
+    my ($self) = @_;
+
+    return $self->{'gconfdir'};
+
+  }
+
+
+# Method: setComponentDirectory
+#
+#      set the correct diectory for a componnent
+#
+#   Parameterss:
+#        comp - component
+sub setComponentDirectory
+{
+    my ($self, $comp) = @_;
+    my $compositeDir = $self->directory();
+
+    return if (not defined($compositeDir) or $compositeDir eq '');
+
+    my $compDir = '' ;
+
+    if ($comp->isa('EBox::Model::Composite')) {
+        # this strange hack is for backwards compability:
+        #  before the composites never have directory so we
+        # must take care to not set nested directories here
+        $compDir = $compositeDir;
+    }
+    elsif ($compositeDir) {
+        $compDir = $compositeDir . '/' . $comp->name();
+    }
+    else {
+        $compDir =  $comp->name();
+    }
+
+    $comp->setDirectory($compDir);
+
+
+}
+
+
+
+
+#  Method: parentRow
+#
+#    if the composite is a submodel of a DataTable (or nested inside one),
+#    return the row where the submodel resides
+#
+#   Returns:
+#       row object or undef if there is not
+#
+#   Warning:
+#      this method is affected fby the bug in ::Composite::parent()
+sub parentRow
+{
+    my ($self) = @_;
+
+    my $parent = $self->parent();
+    if (not $parent) {
+        return undef;
+    }
+
+    my $dir = $self->directory();
+    my @parts = split '/', $dir;
+    my $rowId = $parts[-2];
+
+
+    return $parent->row($rowId);
+}
+
+# Method: filesPaths
+#
+#   Returns:
+#     the paths of the files managed by the composite and all of its nested components
+sub filesPaths
+{
+    my ($self) = @_;
+
+    my @paths;
+    foreach my $comp (@{ $self->components() }) {
+        if ($comp->can('filesPaths')) {
+            push @paths, @{ $comp->filesPaths() };
+        }
+    }
+
+
+    return \@paths;
+}
+
+
+# Method: backupFiles
+#
+#   Make an actual configuration backup of  all the files contained in the
+#   components. This backup will used to discard cahnges if needed
+sub backupFiles
+{
+  my ($self) = @_;
+
+    foreach my $comp (@{ $self->components() }) {
+        if ($comp->can('backupFiles')) {
+            $comp->backupFiles();
+        }
+    }
+
+}
+
+# Method: restoreFiles
+#
+#  Restores the actual configuration backup of files, thus discarding last
+#  changes in files
+sub restoreFiles
+{
+  my ($self) = @_;
+
+    foreach my $comp (@{ $self->components() }) {
+        if ($comp->can('restoreFiles')) {
+            $comp->restoreFiles();
+        }
+    }
+
+}
+
+
+
 1;
