@@ -446,7 +446,7 @@ sub _chooseCompositeUsingIndex
 # 	(PRIVATE)
 #
 #   Mark the model manager as changed. This is done when a change is
-#   done in the models to allow interprocess coherency. 
+#   done in the models to allow interprocess coherency.
 #
 #
 sub _hasChanged
@@ -454,7 +454,10 @@ sub _hasChanged
 
     my ($self) = @_;
 
-    return ($self->{'version'} != $self->_version());
+    my $thisVer = $self->{'version'};
+    my $realVer = $self->_version();
+    return 1 if (not defined($thisVer) or not defined($realVer));
+    return ($thisVer != $realVer);
 
 }
 
