@@ -447,9 +447,9 @@ sub order
 sub sortedBy
 {
 
-    throw EBox::Exceptions::Internal(
-         'It has no sense sortedBy in an one-rowed table'
-                                    );
+    #throw EBox::Exceptions::Internal(
+     #    'It has no sense sortedBy in an one-rowed table'
+      #                              );
 
 }
 
@@ -600,7 +600,7 @@ sub printableActionName
 
 # Method: AUTOLOAD
 #
-#      This method will intercept any call done to undefinede
+#      This method will intercept any call done to undefined
 #      methods. It is used to return the value, printableValue or Type
 #      from an attribute which belongs to the form.
 #
@@ -637,11 +637,23 @@ sub AUTOLOAD
 
       $methodName =~ s/.*:://;
 
+      if ( $methodName eq 'domain' ) {
+          return $self->{gconfmodule}->domain();
+      }
+
       # Ignore DESTROY callings (the Perl destructor)
       if ( $methodName eq 'DESTROY' ) {
           return;
       }
 
+      unless ( UNIVERSAL::can($self, 'row') ) {
+          use Devel::StackTrace;
+          my $trace = new Devel::StackTrace();
+          EBox::debug($trace->as_string());
+          throw EBox::Exceptions::Internal("Not valid autoload method $methodName since "
+                                           . "$self is not a EBox::Model::DataForm");
+      }
+
       my $row = $self->row();
 
       # Get the attribute and its suffix if any <attr>(Value|PrintableValue|Type|)
@@ -829,8 +841,6 @@ sub _setTypedRow
 
     my $dir = $self->{'directory'};
     my $gconfmod = $self->{'gconfmodule'};
-    
-    
 
     my $oldRow = $self->row();
     my $oldValues = $oldRow->hashElements();
@@ -865,7 +875,7 @@ sub _setTypedRow
     $self->validateTypedRow('update', $changedData, $allData);
 
     # If force != true atomaticRemove is enabled it means
-    # the model has to automatically check if the row which is 
+    # the model has to automatically check if the row which is
     # about to be changed is referenced elsewhere and this change
     # produces an inconsistent state
     if ((not $force) and $self->table()->{'automaticRemove'}) {
@@ -873,10 +883,9 @@ sub _setTypedRow
         $manager->warnOnChangeOnId($self->tableName(), 0, $changedData, $oldRow);
     }
 
-    my $modified = undef;
+    my $modified = @changedData;
     for my $data (@changedData) {
-        $data->storeInGConf($gconfmod, "$dir");
-        $modified = 1;
+        $data->storeInGConf($gconfmod, $dir);
     }
 
     # update readonly if change
@@ -912,22 +921,28 @@ sub _row
       my $dir = $self->{'directory'};
       my $gconfmod = $self->{'gconfmodule'};
 
-      
-      unless ($gconfmod->dir_exists("$dir")) {
+    my $storedVersion = $self->_storedVersion();
+    my $cachedVersion = $self->_cachedVersion();;
+    if ((not defined($cachedVersion)) or ($storedVersion != $cachedVersion)) {
+        $self->{'dataCache'} = undef;
+        $self->{'cachedVersion'} = $storedVersion;
+    }
+
+
+      if ((not $gconfmod->dir_exists("$dir")) and (not $self->_volatile())) {
           # Return default values instead
           return $self->_defaultRow();
       }
-      
+
       my $row =  EBox::Model::Row->new(dir => $dir, gconfmodule => $gconfmod);
       $row->setModel($self);
 
       my @values;
       $self->{'cacheOptions'} = {};
-      my $gconfData = $gconfmod->hash_from_dir("$dir");
-      $row->setReadOnly($gconfData->{'readOnly'});
       foreach my $type (@{$self->table()->{'tableDescription'}}) {
           my $element = $type->clone();
-          $element->restoreFromHash($gconfData);
+          $element->setRow($row);
+          $element->restoreFromHash();
           $row->addElement($element);
       }
       # Dummy id for dataform
