@@ -25,7 +25,7 @@ use base 'EBox::Types::Basic';
 sub new
 {
         my $class = shift;
-    	my %opts = @_;
+        my %opts = @_;
 
         unless (exists $opts{'HTMLSetter'}) {
             $opts{'HTMLSetter'} ='/ajax/setter/booleanSetter.mas';
@@ -33,13 +33,58 @@ sub new
         unless (exists $opts{'HTMLViewer'}) {
             $opts{'HTMLViewer'} ='/ajax/viewer/booleanViewer.mas';
         }
-	$opts{'type'} = 'boolean';
+        $opts{'type'} = 'boolean';
 
         my $self = $class->SUPER::new(%opts);
         bless($self, $class);
         return $self;
 }
 
+# Method: isEqualTo
+#
+# Overrides:
+#
+#       <EBox::Types::Abstract::isEqualTo>
+#
+sub isEqualTo
+{
+    my ($self, $other) = @_;
+
+    return $self->cmp($other) == 0;
+
+}
+
+# Method: cmp
+#
+# Overrides:
+#
+#       <EBox::Types::Abstract::cmp>
+#
+sub cmp
+{
+    my ($self, $other) = @_;
+
+    if ((ref $self) ne (ref $other)) {
+        return undef;
+    }
+
+    my $ownValue = $self->value();
+    my $otherValue = $other->value();
+
+
+    if ($ownValue and (not $otherValue)) {
+        return 1;
+    }
+    elsif ((not $ownValue) and $otherValue) {
+        return -1;
+    }
+    else {
+        # the two values are both true or false
+        return 0;
+    }
+
+}
+
 # Group: Protected methods
 
 # Method: _setMemValue
@@ -50,10 +95,10 @@ sub new
 #
 sub _setMemValue
 {
-	my ($self, $params) = @_;
+    my ($self, $params) = @_;
 
-        $self->{'value'} = $params->{$self->fieldName()};
-        $self->{'value'} = 0 unless ( defined ($self->{'value'}) );
+    $self->{'value'} = $params->{$self->fieldName()};
+    $self->{'value'} = 0 unless ( defined ($self->{'value'}) );
 
 }
 
@@ -65,14 +110,14 @@ sub _setMemValue
 #
 sub _storeInGConf
 {
-        my ($self, $gconfmod, $key) = @_;
+    my ($self, $gconfmod, $key) = @_;
 
-	if (defined($self->memValue())) {
-        	$gconfmod->set_bool("$key/" . $self->fieldName(),
-			$self->memValue());
-	} else {
-		$gconfmod->unset("$key/" . $self->fieldName());
-	}
+    if (defined($self->memValue())) {
+        $gconfmod->set_bool("$key/" . $self->fieldName(),
+                $self->memValue());
+    } else {
+        $gconfmod->unset("$key/" . $self->fieldName());
+    }
 }
 
 # Method: _paramIsValid
@@ -119,42 +164,24 @@ sub _paramIsSet
 
   }
 
-
-
-
-
-# Method: cmp
+# Method: _restoreFromHash
 #
 # Overrides:
 #
-#       <EBox::Types::Abstract::cmp>
+#       <EBox::Types::Abstract::_restoreFromHash>
 #
-sub cmp
+sub _restoreFromHash
 {
-    my ($self, $other) = @_;
-    
-    if ((ref $self) ne (ref $other)) {
-        return undef;
+    my ($self, $hash) = @_;
+    return unless ($self->row());
+    my $value;
+    unless ($value = $self->_fetchFromCache()) {
+        my $gconf = $self->row()->GConfModule();
+        $value =  $gconf->get_bool($self->_path() . '/' . $self->fieldName());
+        $self->_addToCache($value);
     }
-
-    my $ownValue = $self->value();
-    my $otherValue = $other->value();
-
-
-    if ($ownValue and (not $otherValue)) {
-        return 1;
-    }
-    elsif ((not $ownValue) and $otherValue) {
-        return -1;
-    }
-    else {
-        # the two values are both true or false
-        return 0;
-    }
-
+    $self->{'value'} = $value;
 }
 
 
-
-
 1;
