@@ -19,18 +19,18 @@
 #       When used in a model, it basically tells you that this field is
 #       referencing another model which has more than one entry.
 #
-#       For example, let's say we have a model which represents a table 
+#       For example, let's say we have a model which represents a table
 #       of internet domains. Each domain is composed of several hosts.
 #       The relation between the domain and the hosts can be expressed
 #       by means of this type.
 #
 #
-#	TODO 
+#	TODO
 #
 #		- Review which methods are necessary and document them
 #		- Implement backview correctly to allow the user to go back
 #		  when he is done with the spawned table
-#		
+#
 package EBox::Types::HasMany;
 
 use strict;
@@ -40,6 +40,7 @@ use base 'EBox::Types::Abstract';
 
 # eBox uses
 use EBox::Model::ModelManager;
+use EBox::Model::CompositeManager;
 
 # Core modules
 use Error qw(:try);
@@ -57,14 +58,14 @@ sub new
     unless (exists $opts{'HTMLViewer'}) {
         $opts{'HTMLViewer'} ='/ajax/viewer/hasManyViewer.mas';
     }
-    
+
     $opts{'type'} = 'hasMany';
     $opts{'unique'} = undef;
     $opts{'editable'} = undef;
     $opts{'optional'} = 1;
 
     my $self = $class->SUPER::new(%opts);
-       
+
     bless($self, $class);
     return $self;
 }
@@ -81,11 +82,23 @@ sub value
     my ($self) = @_;
 
     return '' unless (exists $self->{'foreignModel'});
-    return { 'model' => $self->{'foreignModel'}, , 
+    return { 'model' => $self->{'foreignModel'}, ,
              'directory' => $self->directory() };
 
 }
 
+# Method: foreignModelIsComposite
+#
+# Returns:
+#
+#      bool - wether the foreign model is compostie or not
+#
+sub foreignModelIsComposite
+{
+    my ($self) = @_;
+    return $self->{'foreignModelIsComposite'};
+}
+
 # Method: foreignModel
 #
 #      Get the foreign model which the hasMany type retrieves its
@@ -128,7 +141,14 @@ sub foreignModelInstance
     $directory or
         return undef;
 
-    my $model = EBox::Model::ModelManager->instance()->model($modelName);
+    my $model;
+    if ($self->foreignModelIsComposite()) {
+        $model = EBox::Model::CompositeManager->Instance()->composite($modelName);
+    } else {
+        $model = EBox::Model::ModelManager->instance()->model($modelName);
+    }
+
+
     $model->setDirectory($directory);
 
     return $model;
@@ -145,7 +165,7 @@ sub foreignModelInstance
 sub setDirectory
 {
     my ($self, $directory) = @_;
-    
+
     $self->{'directory'} = $directory;
 }
 
@@ -155,28 +175,33 @@ sub setDirectory
 #
 # Returns:
 #
-#   stirng - directory or undef if there isn't any 
+#   stirng - directory or undef if there isn't any
 sub directory
 {
     my ($self) = @_;
+    my $row = $self->row();
 
-    my $directory = $self->row()->dir() . '/' . $self->row()->id();
+    if (not $row) {
+        return undef;
+    }
+
+    my $directory = $row->dir() . '/' . $row->id();
     $directory .= '/' . $self->fieldName();
 
     return $directory;
 }
 
-# Method: view 
+# Method: view
 #
 #   Return the view for the foreing model
 #
 # Returns:
 #
-#   string - view's url 
-sub view 
+#   string - view's url
+sub view
 {
     my ($self) = @_;
-    
+
    if (exists $self->{'view'}) {
         return $self->{'view'};
    } else {
@@ -184,17 +209,17 @@ sub view
    }
 }
 
-# Method: backView 
+# Method: backView
 #
 #   Return the back view for the foreing model
 #
 # Returns:
 #
-#   stirng - view's url 
-sub backView 
+#   stirng - view's url
+sub backView
 {
     my ($self) = @_;
-    
+
    if (exists $self->{'backView'}) {
         return $self->{'backView'};
    } else {
@@ -209,7 +234,7 @@ sub backView
 # Returns:
 #
 #   string - containing the link
-#   
+#
 sub linkToView
 {
     my ($self) = @_;
@@ -219,7 +244,7 @@ sub linkToView
 
     my $backview = $self->backView();
     my $params="?directory=$directory" . "&backview=$backview";
-    
+
     my $printableName = $self->printableName();
     my $url = $view . $params;
 
@@ -276,7 +301,7 @@ sub isEqualTo
 sub modelView
 {
     my ($self) = @_;
-    return $self->{'modelView'};	
+    return $self->{'modelView'};
 }
 
 # Group: Protected methods
@@ -305,9 +330,14 @@ sub _restoreFromHash
 
       if ( defined ( $self->foreignModelAcquirer() )) {
           my $acquirerFunc = $self->foreignModelAcquirer();
-          $self->{'foreignModel'} = &$acquirerFunc($hashRef);
+          $self->{'foreignModel'} = &$acquirerFunc($self->row());
           try {
-              my $model = EBox::Model::ModelManager->instance()->model($self->{'foreignModel'});
+              my $model = $self->foreignModelInstance();
+              if (not $model) {
+                  throw  EBox::Exceptions::DataNotFound();
+              }
+
+
               $self->{'view'} = '/ebox/' . $model->menuNamespace();
               $self->setDirectory($model->directory());
           } catch EBox::Exceptions::DataNotFound with {
@@ -343,4 +373,146 @@ sub _paramIsSet
 
   }
 
+# Method: filesPaths
+#
+#   Returns:
+#     the paths of the files managed by the submodel and possible rows and sub-submodels
+sub filesPaths
+{
+    my ($self) = @_;
+    my $subModel = $self->foreignModelInstance();
+    if (not $subModel) {
+        return [];
+    }
+
+    if ($subModel->can('filesPaths')) {
+        return $subModel->filesPaths();
+    }
+    else {
+        return []
+    }
+}
+
+# Method: backupFiles
+#
+#   Make an actual configuration backup of all the files contained in the
+#   submodel and potentials rows and nested submodels. This backup will used to discard changes if needed
+sub backupFiles
+{
+  my ($self) = @_;
+
+  my $subModel = $self->foreignModelInstance();
+  if (not $subModel) {
+      return;
+  }
+
+  if ($subModel->can('backupFiles')) {
+      return $subModel->backupFiles();
+  }
+
+}
+
+# Method: restoreFiles
+#
+#  Restores the actual configuration backup of files, thus discarding last
+#  changes in files
+sub restoreFiles
+{
+  my ($self) = @_;
+
+  my $subModel = $self->foreignModelInstance();
+  if (not $subModel) {
+      return;
+  }
+
+  if ($subModel->can('restoreFiles')) {
+      return $subModel->restoreFiles();
+  }
+}
+
+
+sub setModel
+{
+    my ($self, $model, @extraParams) = @_;
+    $self->SUPER::setModel($model, @extraParams);
+
+    if (defined $model) {
+        $self->{modelName} = $model->name();
+        $self->{moduleName} =$model->{gconfmodule}->name(),
+    } else {
+        delete $self->{modelName} ;
+        delete $self->{moduleName} ;
+    }
+}
+
+sub model
+{
+    my ($self) = @_;
+    my $model = $self->SUPER::model();
+
+    if (defined $model) {
+        return $model;
+    }
+
+    if ((not $self->{moduleName}) or (not $self->{modelName})) {
+        return undef;
+    }
+
+    my $module =  EBox::Global->modInstance($self->{moduleName});
+    if (not $module->can('model')) {
+        EBox::warning(
+        'cannot recreate row for ' .  $self->{fieldName} .
+       ' because moduel has not model method'
+
+                     );
+        return undef;
+    }
+
+    $model = $module->model($self->{modelName});
+    defined $model or
+        return undef;
+
+    $self->setModel($model);
+    return $model;
+}
+
+
+sub setRow
+{
+    my ($self, $row, @extraParams) = @_;
+    $self->SUPER::setRow($row, @extraParams);
+
+    if (defined $row) {
+        $self->{rowId} = $row->id();
+    } else {
+        delete $self->{rowId};
+    }
+
+}
+
+
+sub row
+{
+    my ($self) = @_;
+    my $row = $self->SUPER::row();
+
+    if (defined $row) {
+        return $row;
+    }
+
+    if (not ($self->{rowId})) {
+        return undef;
+    }
+
+    my $model = $self->model();
+    $row = $model->row($self->{rowId});
+
+    defined $row or
+        return undef;
+
+    $self->setRow($row);
+    return $row;
+}
+
 1;
+
