@@ -13,8 +13,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# TODO 
-#       * Optimize class. Use reference to fetch selected type 
+# TODO
+#       * Optimize class. Use reference to fetch selected type
 #         instead of transverse array.
 #
 #       * Support automatic unique check
@@ -99,15 +99,15 @@ sub clone
 sub subtype
 {
     my ($self) = @_;
-        
+
     my $selected = $self->selectedType();
-    
+
     foreach my $type (@{$self->{'subtypes'}}) {
         if ($type->fieldName() eq $selected) {
             return $type;
         }
     }
-    
+
     return "";
 }
 
@@ -123,7 +123,7 @@ sub subtype
 sub selectedType
 {
     my ($self) = @_;
-        
+
     if (not $self->{'selectedField'}) {
         my @subtypes = @{$self->{'subtypes'}};
         if (@subtypes > 0) {
@@ -140,7 +140,7 @@ sub selectedType
 sub setSelectedType
 {
     my ($self, $field) = @_;
-    
+
     $self->{'selectedField'} = $field;
 }
 
@@ -154,14 +154,14 @@ sub subtypes
 sub unique
 {
     my ($self) = @_;
-    
+
     my @subtypes = @{$self->{'subtypes'}};
     foreach my $subtype (@subtypes) {
         unless ( $subtype->unique() ) {
             return 0;
         }
     }
-    
+
     return 1;
 }
 
@@ -170,30 +170,32 @@ sub unique
 sub fields
 {
     my ($self) = @_;
-    
+
     my @fields;
     foreach my $type (@{$self->{'subtypes'}}) {
         push (@fields, $type->fields());
-        
+
     }
-    
+
     push (@fields, $self->fieldName() . '_selected');
-    
+
     return @fields;
 }
 
-sub setModel 
+sub setModel
 {
     my ($self, $model) = @_;
-    
+
+    $self->SUPER::setModel($model);
     $AUTOLOAD = 'setModel';
     return $self->AUTOLOAD($model);
 }
- 
+
 sub setRow
 {
     my ($self, $row) = @_;
-    
+
+    $self->SUPER::setRow($row);
     # Call AUTOLOAD method in order not to repeat code
     $AUTOLOAD = 'setRow';
     return $self->AUTOLOAD($row);
@@ -205,21 +207,21 @@ sub paramExist
 
     my $selPar = $self->fieldName() . '_selected';
     my $selected = $params->{$selPar};
-    
+
     if ( (not defined ( $selected )) and
          $self->optional() ) {
         return 1;
     }
-    
-    return 0 unless (defined($selected)); 
-    
+
+    return 0 unless (defined($selected));
+
     foreach my $type (@{$self->{'subtypes'}}) {
         next unless ($type->fieldName() eq $selected);
         # If type has no setter, parameter is not required anyway
         return 1 unless( $type->HTMLSetter() );
         return $type->paramExist($params);
     }
-    
+
     return 0;
 }
 
@@ -228,7 +230,7 @@ sub paramExist
 sub printableValue
 {
     my ($self) = @_;
-    
+
       # Call AUTOLOAD method in order not to repeat code
     $AUTOLOAD = 'printableValue';
     return $self->AUTOLOAD();
@@ -237,7 +239,7 @@ sub printableValue
 sub value
 {
     my ($self) = @_;
-    
+
     # Call AUTOLOAD method in order not to repeat code
     $AUTOLOAD = 'value';
     return $self->AUTOLOAD();
@@ -255,12 +257,22 @@ sub compareToHash
 
 }
 
-
+# Method: isEqualTo
+#
+# Overrides:
+#
+#   <EBox::Types::Abstract::isEqualTo>
+#
 sub isEqualTo
 {
     my ($self, $newObject) = @_;
+    my $comparison = $self->cmp($newObject);
+    if ( defined($comparison) ) {
+        return $comparison == 0;
+    } else {
+        return 0;
+    }
 
-    return ($self->printableValue() eq $newObject->printableValue());
 }
 
 # Method: HTMLSetter
@@ -282,14 +294,14 @@ sub isEqualTo
 sub HTMLSetter
 {
     my ($self) = @_;
-    
+
     my $definedSetter = 0;
     foreach my $type (@{$self->{'subtypes'}}) {
         next unless ( defined ( $type->HTMLSetter() ));
         $definedSetter = 1;
         last;
     }
-    
+
     if ( $definedSetter ) {
         return '/ajax/setter/unionSetter.mas';
     } else {
@@ -298,10 +310,10 @@ sub HTMLSetter
 
 }
 
-sub HTMLViewer 
+sub HTMLViewer
 {
     my ($self) = @_;
-    
+
     # Call AUTOLOAD method in order not to repeat code
     $AUTOLOAD = 'HTMLViewer';
     return $self->AUTOLOAD();
@@ -327,23 +339,30 @@ sub AUTOLOAD
 {
     my ($self, @params) = @_;
     my $methodName = $AUTOLOAD;
-    
+
     # Remove namespaces
     $methodName =~ s/.*:://;
-    
+
     # Ignore DESTROY callings (the Perl destructor)
     if ( $methodName eq 'DESTROY' ) {
         return;
     }
-    
+
+    # setRow and setModel must be run for all subtypes
+    if ($methodName eq 'setRow' or $methodName eq 'setModel') {
+        foreach my $subtype (@{$self->{'subtypes'}}) {
+            $subtype->$methodName(@params);
+        }
+    }
+
     # Call the method from the selected type
     my $selected = $self->selectedType();
-    
+
     unless ( defined ( $selected )) {
         throw EBox::Exceptions::Internal('There is no selected type ' .
                                          "to call its own method $methodName");
     }
-    
+
     foreach my $subtype (@{$self->{'subtypes'}}) {
         next unless ($subtype->fieldName() eq $selected);
         # Check if the method is defined
@@ -354,7 +373,7 @@ sub AUTOLOAD
                                              'in type ' . $subtype->type());
         }
     }
-    
+
   }
 
 # Group: Protected methods
@@ -368,7 +387,7 @@ sub AUTOLOAD
 sub _setMemValue
 {
     my ($self, $params) = @_;
-    
+
     my $selPar = $self->fieldName() . '_selected';
     my $selected = $params->{$selPar};
 
@@ -391,15 +410,15 @@ sub _setMemValue
 sub _storeInGConf
 {
     my ($self, $gconfmod, $key) = @_;
-    
+
     my $selected = $self->selectedType();
-    
+
     foreach my $type (@{$self->{'subtypes'}}) {
         # Every union type should be stored in order to unset its
         # value if it has not got one
         $type->storeInGConf($gconfmod, $key);
         if ($type->fieldName() eq $selected) {
-              my $selKey = "$key/" . $self->fieldName() 
+              my $selKey = "$key/" . $self->fieldName()
                   . '_selected';
               $gconfmod->set_string($selKey, $self->selectedType());
           }
@@ -415,18 +434,24 @@ sub _storeInGConf
 sub _restoreFromHash
 {
     my ($self, $hash) = @_;
-    
+
     my $selPar = $self->fieldName() . '_selected';
-    
-    my $selected = $hash->{$selPar};
-        
+
+    return unless ($self->row());
+    my $selected;
+    unless ($selected = $self->_fetchFromCache()) {
+        my $gconf = $self->row()->GConfModule();
+        my $path = $self->_path();
+        $selected =  $gconf->get_string($path . '/' . $selPar);
+        $self->_addToCache($selected);
+    }
+
     foreach my $type (@{$self->{'subtypes'}}) {
         next unless ($type->fieldName() eq $selected);
-        
-        $type->restoreFromHash($hash);
+        $type->restoreFromHash();
         $self->setSelectedType($selected);
     }
-        
+
 }
 
 # Method: _paramIsValid
@@ -449,23 +474,23 @@ sub _paramIsValid
 sub _paramIsSet
 {
     my ($self, $params) = @_;
-    
+
     my $selPar = $self->fieldName() . '_selected';
     my $selected = $params->{$selPar};
 
     unless ( defined ( $selected )) {
         return 0;
     }
-    
+
     foreach my $type (@{$self->{'subtypes'}}) {
         next unless ($type->fieldName() eq $selected);
         # If type has no setter, parameter is not required anyway
           return 1 unless( $type->HTMLSetter() );
         return $type->_paramIsSet($params);
     }
-    
+
     return 0;
-    
+
 }
 
 # Method: _setValue
@@ -477,14 +502,46 @@ sub _paramIsSet
 sub _setValue
 {
     my ($self, $value) = @_;
-    
+
     my ($selectedField, $selectedValue) = each ( %{$value} );
-    
+
     $self->setSelectedType( $selectedField );
-    
+
     # Call AUTOLOAD method in order not to repeat code
     $AUTOLOAD = '_setValue';
     return $self->AUTOLOAD($selectedValue);
  }
 
+# Method: cmp
+#
+# Overrides:
+#
+#      <EBox::Types::Abstract::cmp>
+#
+# Returns:
+#
+#      -1 - if all simpler types from self are lower than compareType
+#
+#       0 - if all simpler types from self are equal to compareType
+#
+#       1 - if all simpler types from self are higher than compareType
+#
+#       undef - otherwise
+#
+sub cmp
+{
+    my ($self, $compareType) = @_;
+
+    unless ( (ref $self) eq (ref $compareType) ) {
+        return undef;
+    }
+
+
+    my $selfSelected = $self->subtype();
+    my $compareSelected = $compareType->subtype();
+
+
+    return $selfSelected->cmp($compareSelected);
+}
+
 1;
